==> libreoffice-still-sdk-24.2.7-5-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.js <==
var servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel =
[
    [ "UnoControlModel", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#ac1ee7df8246117083090d716cae44bb0", null ],
    [ "Align", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#acaaef3a437193c979a93656446e56891", null ],
    [ "BackgroundColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#a85c9847c6ec77e673c618e26b2aa0746", null ],
    [ "Border", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#a54d3ff280d892218d71e667f81ce99d4", null ],
    [ "BorderColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#a79f9492eb784a2ae0323d4d31b179a8a", null ],
    [ "Enabled", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#add0e09d5a83268ea58802b8b35fb4dfa", null ],
    [ "FontDescriptor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#a9e110c55c0a3426a353ded5f029cd4e0", null ],
    [ "FontEmphasisMark", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#ac5c5781ab84a14cafec66b192fbdeae9", null ],
    [ "FontRelief", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#ac2b8dcc269c9ef6d27978db9b76caa43", null ],
    [ "HelpText", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#a7e52ef40b5265c017585bf7d607ee31a", null ],
    [ "HelpURL", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#a755e2d2c27383c5201ee98aaed028954", null ],
    [ "HighlightColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#a9f6d16e9f74137fc9e3158e8928c8572", null ],
    [ "HighlightTextColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#a9b462e58b5c1c9058cd57041eb9c83e2", null ],
    [ "Label", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#a0999f1070ce4923004bfb388671f0387", null ],
    [ "MultiLine", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#afb440b6460d9580ab91a3fed3dd3670b", null ],
    [ "NoLabel", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#a43a3dfa98249519be1fcd071711e0b87", null ],
    [ "Printable", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#ad75a741ee6d8f45340ba0bbb7771f05b", null ],
    [ "TextColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#a01c58818488ca5e1d235d71b625efa0e", null ],
    [ "TextLineColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#a7de6f39eb42c328f77d4db6f6861bd6b", null ],
    [ "VerticalAlign", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#aeeee894b4f8f059ee92ccef71579845a", null ]
];

==> libreoffice-still-sdk-25.2.7-5-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.js <==
var servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel =
[
    [ "com::sun::star::awt::UnoControlModel", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#ac1ee7df8246117083090d716cae44bb0", null ],
    [ "Align", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#acaaef3a437193c979a93656446e56891", null ],
    [ "BackgroundColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#a85c9847c6ec77e673c618e26b2aa0746", null ],
    [ "Border", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#a54d3ff280d892218d71e667f81ce99d4", null ],
    [ "BorderColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#a79f9492eb784a2ae0323d4d31b179a8a", null ],
    [ "Enabled", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#add0e09d5a83268ea58802b8b35fb4dfa", null ],
    [ "FontDescriptor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#a9e110c55c0a3426a353ded5f029cd4e0", null ],
    [ "FontEmphasisMark", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#ac5c5781ab84a14cafec66b192fbdeae9", null ],
    [ "FontRelief", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#ac2b8dcc269c9ef6d27978db9b76caa43", null ],
    [ "HelpText", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#a7e52ef40b5265c017585bf7d607ee31a", null ],
    [ "HelpURL", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#a755e2d2c27383c5201ee98aaed028954", null ],
    [ "HighlightColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#a9f6d16e9f74137fc9e3158e8928c8572", null ],
    [ "HighlightTextColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#a9b462e58b5c1c9058cd57041eb9c83e2", null ],
    [ "Label", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#a0999f1070ce4923004bfb388671f0387", null ],
    [ "MultiLine", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#afb440b6460d9580ab91a3fed3dd3670b", null ],
    [ "NoLabel", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#a43a3dfa98249519be1fcd071711e0b87", null ],
    [ "Printable", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#ad75a741ee6d8f45340ba0bbb7771f05b", null ],
    [ "TextColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#a01c58818488ca5e1d235d71b625efa0e", null ],
    [ "TextLineColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#a7de6f39eb42c328f77d4db6f6861bd6b", null ],
    [ "VerticalAlign", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlFixedTextModel.html#aeeee894b4f8f059ee92ccef71579845a", null ]
];
